#!/bin/bash

DIR="$(pwd)"
BUILD_DIR="$DIR/build"
AS_INSTALLATION="$1"
export JBOSS_HOME="$BUILD_DIR/jboss-eap"
AS_CONFIG_CLI="${DIR}/bz-1127938.cli"
LDAP_SERVER="${DIR}/ldap-server.jar"
LDAP_SERVER_DATA="${DIR}/bz-1127938.ldif"

AS_LOG="$BUILD_DIR/server-console.log"
CLI_LOG="$BUILD_DIR/cli.log"
CURL_LOG="$BUILD_DIR/curl.log"
LDAP_LOG="$BUILD_DIR/ldap.log"

if [ ! -d "$AS_INSTALLATION" ]; then
	echo "Please provide location of JBOSS_HOME as a first paramenter. eg $0 /home/test/jboss-eap-6.2"
	exit 1
fi

if [ -d "$BUILD_DIR" ]; then
    echo "Removing old build directory"
	rm -rf "$BUILD_DIR"
fi
echo "Creating build directory $BUILD_DIR"
mkdir "$BUILD_DIR"

echo "Copying the EAP to $JBOSS_HOME"
cp -r "$AS_INSTALLATION" "$JBOSS_HOME"

cd "$BUILD_DIR"

echo "Adding system property to standalone.conf/domain.conf to enable patch functionality"
echo 'JAVA_OPTS="$JAVA_OPTS -Dorg.jboss.as.domain.management.security.LdapGroupSearcherService.IGNORE_NONEXISTENT_ROLE=true"' >> "$JBOSS_HOME/bin/standalone.conf"
echo 'HOST_CONTROLLER_JAVA_OPTS="$HOST_CONTROLLER_JAVA_OPTS -Dorg.jboss.as.domain.management.security.LdapGroupSearcherService.IGNORE_NONEXISTENT_ROLE=true"' >> "$JBOSS_HOME/bin/domain.conf"

echo "Starting LDAP server"
java -jar "$LDAP_SERVER" "$LDAP_SERVER_DATA" >>"$LDAP_LOG" 2>&1 &
LDAP_PID=$!

echo "Starting EAP"
"$JBOSS_HOME/bin/standalone.sh" >>"$AS_LOG" 2>&1 &
sleep 90

echo "Configuring EAP using CLI"
"$JBOSS_HOME/bin/jboss-cli.sh" -c "--file=${AS_CONFIG_CLI}" >>"$CLI_LOG" 2>&1
sleep 60

echo "Trying to reproduce the issue"
MGMT_RESPONSE_CODE=$(curl --write-out %{http_code} --silent --output "$CURL_LOG" --basic -u jduke:theduke -L http://localhost:9990/management --header "Content-Type: application/json" -d '{"operation" : "whoami"}')

echo "Stopping the EAP"
"$JBOSS_HOME/bin/jboss-cli.sh" -c ':shutdown' >>"$CLI_LOG" 2>&1

echo "Stopping the LDAP server"
kill $LDAP_PID
sleep 5

if [ "${MGMT_RESPONSE_CODE}" != "200" ]; then
	echo "Issue reproduced!!!"
	exit 1;
fi;

echo "Unable to reproduce the issue. Seems fixed."

cd "$DIR"
echo "Removing build directory $BUILD_DIR"
rm -rf "$BUILD_DIR"
